@@ -603,18 +603,18 @@ function set_globals {
 
   #####
   # glaxnimate
-  CONFIG[13]="cmake -G Ninja -DCMAKE_PREFIX_PATH=$QTDIR -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR"
+  CONFIG[13]="cmake -G Ninja -D CMAKE_PREFIX_PATH=$QTDIR -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -D Python3_FIND_REGISTRY=NEVER"
   if [ "$DEBUG_BUILD" = "1" ]; then
-    CONFIG[13]="${CONFIG[13]} -DCMAKE_BUILD_TYPE=RelWithDebInfo"
+    CONFIG[13]="${CONFIG[13]} -D CMAKE_BUILD_TYPE=RelWithDebInfo"
   else
-    CONFIG[13]="${CONFIG[13]} -DCMAKE_BUILD_TYPE=Release"
+    CONFIG[13]="${CONFIG[13]} -D CMAKE_BUILD_TYPE=Release"
   fi
   CFLAGS_[13]="$ASAN_CFLAGS $CFLAGS"
   LDFLAGS_[13]="$ASAN_LDFLAGS $LDFLAGS"
 
   #####
   # gopro2gpx
-  CONFIG[14]="cmake -G Ninja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG"
+  CONFIG[14]="cmake -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG"
   CFLAGS_[14]="$CFLAGS"
   LDFLAGS_[14]="$LDFLAGS"
 }
