@@ -3,26 +3,28 @@ VERSION="$1"
 sudo xcode-select -s /Applications/Xcode.app/
 
 SIGNER="Developer ID Application: Meltytech, LLC (Y6RX44QG2G)"
+find ~/Desktop/Shotcut.app/Contents/lib -type f -exec codesign --options=runtime -v -s "$SIGNER" {} \;
 find ~/Desktop/Shotcut.app/Contents/Frameworks -type f -exec codesign --options=runtime -v -s "$SIGNER" {} \;
 find ~/Desktop/Shotcut.app/Contents/PlugIns -type f -exec codesign --options=runtime -v -s "$SIGNER" {} \;
 find ~/Desktop/Shotcut.app/Contents/Resources -type f -exec codesign --options=runtime -v -s "$SIGNER" {} \;
 xattr -cr ~/Desktop/Shotcut.app
 codesign --options=runtime -v -s "$SIGNER" \
-  --entitlements ~/Projects/Shotcut/src/shotcut/scripts/notarization.entitlements \
-  ~/Desktop/Shotcut.app/Contents/MacOS/{melt,ffmpeg,ffplay,ffprobe}
+  --entitlements ./notarization.entitlements \
+  ~/Desktop/Shotcut.app/Contents/MacOS/{melt,ffmpeg,ffplay,ffprobe,glaxnimate,gopro2gpx}
 codesign --options=runtime -v -s "$SIGNER" \
-  --entitlements ~/Projects/Shotcut/src/shotcut/scripts/notarization.entitlements \
+  --entitlements ./notarization.entitlements \
   ~/Desktop/Shotcut.app
 codesign --verify --deep --strict --verbose=2 ~/Desktop/Shotcut.app
 spctl -a -t exec -vv ~/Desktop/Shotcut.app
 
-rm -rf ~/tmp/*
-mv ~/Desktop/Shotcut.app ~/tmp
-ln -s /Applications ~/tmp
-cp ~/Projects/Shotcut/src/shotcut/COPYING ~/tmp
+TMP=$(mktemp -d)
+mv ~/Desktop/Shotcut.app $TMP
+ln -s /Applications $TMP
+cp ../COPYING $TMP
 rm ~/Desktop/shotcut-macos-${VERSION}.dmg
-hdiutil create -srcfolder ~/tmp -volname Shotcut -format UDBZ -size 300m \
+hdiutil create -srcfolder $TMP -volname Shotcut -format UDBZ -size 600m \
   ~/Desktop/shotcut-macos-${VERSION}.dmg
+rm -rf $TMP
 
 ./notarize.sh ~/Desktop/shotcut-macos-${VERSION}.dmg
 
