@@ -1,6 +1,5 @@
 /*
- * Copyright (c) 2012 Meltytech, LLC
- * Author: Dan Dennedy <dan@dennedy.org>
+ * Copyright (c) 2012-2022 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,7 +30,7 @@ AddEncodePresetDialog::~AddEncodePresetDialog()
     delete ui;
 }
 
-void AddEncodePresetDialog::setProperties(const QString& properties)
+void AddEncodePresetDialog::setProperties(const QString &properties)
 {
     ui->propertiesEdit->setPlainText(properties);
 }
@@ -43,5 +42,9 @@ QString AddEncodePresetDialog::presetName() const
 
 QString AddEncodePresetDialog::properties() const
 {
+    const auto &extension = ui->extensionEdit->text();
+    if (!extension.isEmpty()) {
+        return ui->propertiesEdit->toPlainText() + "\nmeta.preset.extension=" + extension;
+    }
     return ui->propertiesEdit->toPlainText();
 }
