@@ -1,6 +1,5 @@
 /*
- * Copyright (c) 2012 Meltytech, LLC
- * Author: Dan Dennedy <dan@dennedy.org>
+ * Copyright (c) 2012-2022 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +23,7 @@ DurationDialog::DurationDialog(QWidget *parent) :
     ui(new Ui::DurationDialog)
 {
     ui->setupUi(this);
+    connect(ui->spinBox, &TimeSpinBox::accepted, this, &QDialog::accept);
 }
 
 DurationDialog::~DurationDialog()
