@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2021 Meltytech, LLC
+ * Copyright (c) 2013-2022 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,11 @@
 #include <QAction>
 #include <QIcon>
 #include <Logger.h>
+
+#include "actions.h"
+#include "mainwindow.h"
+#include "controllers/filtercontroller.h"
+#include "qmltypes/qmlapplication.h"
 #include "qmltypes/qmlfilter.h"
 #include "qmltypes/qmlutilities.h"
 #include "qmltypes/qmlview.h"
@@ -33,15 +38,19 @@
 #include "models/attachedfiltersmodel.h"
 #include "mltcontroller.h"
 
-FiltersDock::FiltersDock(MetadataModel* metadataModel, AttachedFiltersModel* attachedModel, QWidget *parent) :
+FiltersDock::FiltersDock(MetadataModel *metadataModel, AttachedFiltersModel *attachedModel,
+                         QWidget *parent) :
     QDockWidget(tr("Filters"), parent),
     m_qview(QmlUtilities::sharedEngine(), this)
 {
     LOG_DEBUG() << "begin";
     setObjectName("FiltersDock");
-    QIcon filterIcon = QIcon::fromTheme("view-filter", QIcon(":/icons/oxygen/32x32/actions/view-filter.png"));
+    QIcon filterIcon = QIcon::fromTheme("view-filter",
+                                        QIcon(":/icons/oxygen/32x32/actions/view-filter.png"));
     setWindowIcon(filterIcon);
     toggleViewAction()->setIcon(windowIcon());
+    setupActions();
+
     m_qview.setFocusPolicy(Qt::StrongFocus);
     m_qview.quickWindow()->setPersistentSceneGraph(false);
 #ifdef Q_OS_MAC
@@ -65,10 +74,11 @@ FiltersDock::FiltersDock(MetadataModel* metadataModel, AttachedFiltersModel* att
     LOG_DEBUG() << "end";
 }
 
-void FiltersDock::setCurrentFilter(QmlFilter* filter, QmlMetadata* meta, int index)
+void FiltersDock::setCurrentFilter(QmlFilter *filter, QmlMetadata *meta, int index)
 {
     if (filter && filter->producer().is_valid()) {
         m_producer.setProducer(filter->producer());
+        m_producer.seek(MLT.producer()->position());
     } else {
         Mlt::Producer emptyProducer(mlt_producer(0));
         m_producer.setProducer(emptyProducer);
@@ -76,10 +86,11 @@ void FiltersDock::setCurrentFilter(QmlFilter* filter, QmlMetadata* meta, int ind
     m_qview.rootContext()->setContextProperty("filter", filter);
     m_qview.rootContext()->setContextProperty("metadata", meta);
     if (filter)
-        connect(filter, SIGNAL(changed()), SIGNAL(changed()));
+        connect(filter, SIGNAL(changed(QString)), SIGNAL(changed()));
     else
         disconnect(this, SIGNAL(changed()));
-    QMetaObject::invokeMethod(m_qview.rootObject(), "setCurrentFilter", Q_ARG(QVariant, QVariant(index)));
+    QMetaObject::invokeMethod(m_qview.rootObject(), "setCurrentFilter", Q_ARG(QVariant,
+                                                                              QVariant(index)));
 }
 
 bool FiltersDock::event(QEvent *event)
@@ -115,7 +126,7 @@ void FiltersDock::onSeeked(int position)
     }
 }
 
-void FiltersDock::onShowFrame(const SharedFrame& frame)
+void FiltersDock::onShowFrame(const SharedFrame &frame)
 {
     if (m_producer.producer().is_valid()) {
         int position = frame.get_position();
@@ -128,11 +139,19 @@ void FiltersDock::openFilterMenu() const
     QMetaObject::invokeMethod(m_qview.rootObject(), "openFilterMenu");
 }
 
+void FiltersDock::onServiceInChanged(int delta, Mlt::Service *service)
+{
+    if (delta && service && m_producer.producer().is_valid()
+            && service->get_service() == m_producer.producer().get_service()) {
+        emit producerInChanged(delta);
+    }
+}
+
 void FiltersDock::resetQview()
 {
     LOG_DEBUG() << "begin";
     if (m_qview.status() != QQuickWidget::Null) {
-        QObject* root = m_qview.rootObject();
+        QObject *root = m_qview.rootObject();
         QObject::disconnect(root, SIGNAL(currentFilterRequested(int)),
                             this, SIGNAL(currentFilterRequested(int)));
 
@@ -154,6 +173,61 @@ void FiltersDock::resetQview()
     m_qview.setSource(source);
 
     QObject::connect(m_qview.rootObject(), SIGNAL(currentFilterRequested(int)),
-        SIGNAL(currentFilterRequested(int)));
+                     SIGNAL(currentFilterRequested(int)));
     emit currentFilterRequested(QmlFilter::NoCurrentFilter);
 }
+
+void FiltersDock::setupActions()
+{
+    QIcon icon;
+    QAction *action;
+
+    action = new QAction(tr("Add"), this);
+    action->setShortcut(QKeySequence(Qt::Key_F));
+    action->setToolTip(tr("Choose a filter to add"));
+    icon = QIcon::fromTheme("list-add",
+                            QIcon(":/icons/oxygen/32x32/actions/list-add.png"));
+    action->setIcon(icon);
+    connect(action, &QAction::triggered, this, [ = ]() {
+        show();
+        raise();
+        m_qview.setFocus();
+        openFilterMenu();
+    });
+    addAction(action);
+    Actions.add("filtersAddFilterAction", action, windowTitle());
+
+    action = new QAction(tr("Remove"), this);
+    action->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_F));
+    action->setToolTip(tr("Remove selected filter"));
+    icon = QIcon::fromTheme("list-remove",
+                            QIcon(":/icons/oxygen/32x32/actions/list-remove.png"));
+    action->setIcon(icon);
+    connect(action, &QAction::triggered, this, [ = ]() {
+        MAIN.filterController()->removeCurrent();
+    });
+    addAction(action);
+    Actions.add("filtersRemoveFilterAction", action, windowTitle());
+
+    action = new QAction(tr("Copy Filters"), this);
+    action->setToolTip(tr("Copy the filters to the clipboard"));
+    icon = QIcon::fromTheme("edit-copy",
+                            QIcon(":/icons/oxygen/32x32/actions/edit-copy.png"));
+    action->setIcon(icon);
+    connect(action, &QAction::triggered, this, [ = ]() {
+        QmlApplication::singleton().copyFilters();
+    });
+    addAction(action);
+    Actions.add("filtersCopyFiltersAction", action, windowTitle());
+
+    action = new QAction(tr("Paste Filters"), this);
+    action->setToolTip(tr("Paste the filters from the clipboard"));
+    icon = QIcon::fromTheme("edit-paste",
+                            QIcon(":/icons/oxygen/32x32/actions/edit-paste.png"));
+    action->setIcon(icon);
+    connect(action, &QAction::triggered, this, [ = ]() {
+        QmlApplication::singleton().pasteFilters();
+    });
+    addAction(action);
+    Actions.add("filtersPasteFiltersAction", action, windowTitle());
+}
