@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2011-2020 Meltytech, LLC
- * 
+ * Copyright (c) 2011-2022 Meltytech, LLC
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -43,7 +43,7 @@ class Filter;
 class RenderThread;
 class FrameRenderer;
 
-typedef void* ( *thread_function_t )( void* );
+typedef void *( *thread_function_t )( void * );
 
 class GLWidget : public QQuickWidget, public Controller, protected QOpenGLFunctions
 {
@@ -58,53 +58,83 @@ public:
     GLWidget(QObject *parent = 0);
     ~GLWidget();
 
-    void createThread(RenderThread** thread, thread_function_t function, void* data);
+    void createThread(RenderThread **thread, thread_function_t function, void *data);
     void startGlsl();
     void stopGlsl();
-    int setProducer(Mlt::Producer*, bool isMulti = false);
+    int setProducer(Mlt::Producer *, bool isMulti = false);
     int reconfigure(bool isMulti);
 
-    void play(double speed = 1.0) {
+    void play(double speed = 1.0)
+    {
         Controller::play(speed);
         if (speed == 0) emit paused();
         else emit playing();
     }
-    void seek(int position) {
+    void seek(int position)
+    {
         Controller::seek(position);
         emit paused();
     }
     void refreshConsumer(bool scrubAudio = false);
-    void pause() {
+    void pause()
+    {
         Controller::pause();
         emit paused();
     }
-    int displayWidth() const { return m_rect.width(); }
-    int displayHeight() const { return m_rect.height(); }
+    int displayWidth() const
+    {
+        return m_rect.width();
+    }
+    int displayHeight() const
+    {
+        return m_rect.height();
+    }
 
-    QObject* videoWidget() { return this; }
-    Filter* glslManager() const { return m_glslManager; }
-    QRectF rect() const { return m_rect; }
-    int grid() const { return m_grid; }
-    float zoom() const { return m_zoom * MLT.profile().width() / m_rect.width(); }
+    QObject *videoWidget()
+    {
+        return this;
+    }
+    Filter *glslManager() const
+    {
+        return m_glslManager;
+    }
+    QRectF rect() const
+    {
+        return m_rect;
+    }
+    int grid() const
+    {
+        return m_grid;
+    }
+    float zoom() const
+    {
+        return m_zoom * MLT.profile().width() / m_rect.width();
+    }
     QPoint offset() const;
     QImage image() const;
     bool imageIsProxy() const;
     void requestImage() const;
-    bool snapToGrid() const { return m_snapToGrid; }
-    int maxTextureSize() const { return m_maxTextureSize; }
+    bool snapToGrid() const
+    {
+        return m_snapToGrid;
+    }
+    int maxTextureSize() const
+    {
+        return m_maxTextureSize;
+    }
 
 public slots:
-    void onFrameDisplayed(const SharedFrame& frame);
+    void onFrameDisplayed(const SharedFrame &frame);
     void setGrid(int grid);
     void setZoom(float zoom);
     void setOffsetX(int x);
     void setOffsetY(int y);
     void setBlankScene();
-    void setCurrentFilter(QmlFilter* filter, QmlMetadata* meta);
+    void setCurrentFilter(QmlFilter *filter, QmlMetadata *meta);
     void setSnapToGrid(bool snap);
 
 signals:
-    void frameDisplayed(const SharedFrame& frame);
+    void frameDisplayed(const SharedFrame &frame);
     void dragStarted();
     void seekTo(int x);
     void gpuNotSupported();
@@ -114,7 +144,7 @@ signals:
     void rectChanged();
     void gridChanged();
     void zoomChanged();
-    void offsetChanged();
+    void offsetChanged(const QPoint &offset = QPoint());
     void imageReady();
     void snapToGridChanged();
     void toggleZoom(bool);
@@ -123,16 +153,16 @@ private:
     QRectF m_rect;
     int m_grid;
     GLuint m_texture[3];
-    QOpenGLShaderProgram* m_shader;
+    QOpenGLShaderProgram *m_shader;
     QPoint m_dragStart;
-    Filter* m_glslManager;
+    Filter *m_glslManager;
     QSemaphore m_initSem;
     bool m_isInitialized;
-    Event* m_threadStartEvent;
-    Event* m_threadStopEvent;
-    Event* m_threadCreateEvent;
-    Event* m_threadJoinEvent;
-    FrameRenderer* m_frameRenderer;
+    Event *m_threadStartEvent;
+    Event *m_threadStopEvent;
+    Event *m_threadCreateEvent;
+    Event *m_threadJoinEvent;
+    FrameRenderer *m_frameRenderer;
     int m_projectionLocation;
     int m_modelViewLocation;
     int m_vertexLocation;
@@ -142,7 +172,7 @@ private:
     float m_zoom;
     QPoint m_offset;
     QOffscreenSurface m_offscreenSurface;
-    QOpenGLContext* m_shareContext;
+    QOpenGLContext *m_shareContext;
     SharedFrame m_sharedFrame;
     QMutex m_mutex;
     QUrl m_savedQmlSource;
@@ -150,8 +180,10 @@ private:
     QTimer m_refreshTimer;
     bool m_scrubAudio;
     GLint m_maxTextureSize;
+    QPoint m_mousePosition;
 
-    static void on_frame_show(mlt_consumer, GLWidget* widget, mlt_event_data);
+
+    static void on_frame_show(mlt_consumer, GLWidget *widget, mlt_event_data);
 
 private slots:
     void initializeGL();
@@ -161,11 +193,11 @@ private slots:
     void onRefreshTimeout();
 
 protected:
-    void resizeEvent(QResizeEvent* event);
+    void resizeEvent(QResizeEvent *event);
     void mousePressEvent(QMouseEvent *);
     void mouseMoveEvent(QMouseEvent *);
-    void keyPressEvent(QKeyEvent* event);
-    bool event(QEvent* event);
+    void keyPressEvent(QKeyEvent *event);
+    bool event(QEvent *event);
     void createShader();
 };
 
@@ -173,44 +205,53 @@ class RenderThread : public QThread
 {
     Q_OBJECT
 public:
-    RenderThread(thread_function_t function, void* data, QOpenGLContext *context, QSurface* surface);
+    RenderThread(thread_function_t function, void *data, QOpenGLContext *context, QSurface *surface);
 
 protected:
     void run();
 
 private:
     thread_function_t m_function;
-    void* m_data;
-    QOpenGLContext* m_context;
-    QSurface* m_surface;
+    void *m_data;
+    QOpenGLContext *m_context;
+    QSurface *m_surface;
 };
 
 class FrameRenderer : public QThread
 {
     Q_OBJECT
 public:
-    FrameRenderer(QOpenGLContext* shareContext, QSurface* surface);
+    FrameRenderer(QOpenGLContext *shareContext, QSurface *surface);
     ~FrameRenderer();
-    QSemaphore* semaphore() { return &m_semaphore; }
-    QOpenGLContext* context() const { return m_context; }
+    QSemaphore *semaphore()
+    {
+        return &m_semaphore;
+    }
+    QOpenGLContext *context() const
+    {
+        return m_context;
+    }
     SharedFrame getDisplayFrame();
     Q_INVOKABLE void showFrame(Mlt::Frame frame);
     void requestImage();
-    QImage image() const { return m_image; }
+    QImage image() const
+    {
+        return m_image;
+    }
 
 public slots:
     void cleanup();
 
 signals:
     void textureReady(GLuint yName, GLuint uName = 0, GLuint vName = 0);
-    void frameDisplayed(const SharedFrame& frame);
+    void frameDisplayed(const SharedFrame &frame);
     void imageReady();
 
 private:
     QSemaphore m_semaphore;
     SharedFrame m_displayFrame;
-    QOpenGLContext* m_context;
-    QSurface* m_surface;
+    QOpenGLContext *m_context;
+    QSurface *m_surface;
     qint64 m_previousMSecs;
     bool m_imageRequested;
     QImage m_image;
@@ -218,7 +259,7 @@ private:
 public:
     GLuint m_renderTexture[3];
     GLuint m_displayTexture[3];
-    QOpenGLFunctions_3_2_Core* m_gl32;
+    QOpenGLFunctions_3_2_Core *m_gl32;
 };
 
 } // namespace
