@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Meltytech, LLC
+ * Copyright (c) 2012-2022 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,10 +19,13 @@
 #define ABSTRACTJOB_H
 
 #include "postjobaction.h"
+#include "settings.h"
+
 #include <QProcess>
 #include <QModelIndex>
 #include <QList>
-#include <QTime>
+#include <QElapsedTimer>
+#include <QThread>
 
 class QAction;
 class QStandardItem;
@@ -31,22 +34,34 @@ class AbstractJob : public QProcess
 {
     Q_OBJECT
 public:
-    explicit AbstractJob(const QString& name);
+    explicit AbstractJob(const QString &name, QThread::Priority priority = Settings.jobPriority());
     virtual ~AbstractJob() {}
 
-    void setStandardItem(QStandardItem* item);
-    QStandardItem* standardItem();
+    void setStandardItem(QStandardItem *item);
+    QStandardItem *standardItem();
     bool ran() const;
     bool stopped() const;
-    void appendToLog(const QString&);
+    void appendToLog(const QString &);
     QString log() const;
-    QString label() const { return m_label; }
-    void setLabel(const QString& label);
-    QList<QAction*> standardActions() const { return m_standardActions; }
-    QList<QAction*> successActions() const { return m_successActions; }
+    QString label() const
+    {
+        return m_label;
+    }
+    void setLabel(const QString &label);
+    QList<QAction *> standardActions() const
+    {
+        return m_standardActions;
+    }
+    QList<QAction *> successActions() const
+    {
+        return m_successActions;
+    }
     QTime estimateRemaining(int percent);
-    QTime time() const { return m_totalTime; }
-    void setPostJobAction(PostJobAction* action);
+    QElapsedTimer time() const
+    {
+        return m_totalTime;
+    }
+    void setPostJobAction(PostJobAction *action);
 
 public slots:
     void start(const QString &program, const QStringList &arguments);
@@ -54,13 +69,13 @@ public slots:
     virtual void stop();
 
 signals:
-    void progressUpdated(QStandardItem* item, int percent);
-    void finished(AbstractJob* job, bool isSuccess, QString failureTime = QString());
+    void progressUpdated(QStandardItem *item, int percent);
+    void finished(AbstractJob *job, bool isSuccess, QString failureTime = QString());
 
 protected:
-    QList<QAction*> m_standardActions;
-    QList<QAction*> m_successActions;
-    QStandardItem*  m_item;
+    QList<QAction *> m_standardActions;
+    QList<QAction *> m_successActions;
+    QStandardItem  *m_item;
 
 protected slots:
     virtual void onFinished(int exitCode, QProcess::ExitStatus exitStatus = QProcess::NormalExit);
@@ -68,17 +83,18 @@ protected slots:
     virtual void onStarted();
 
 private slots:
-    void onProgressUpdated(QStandardItem*, int percent);
+    void onProgressUpdated(QStandardItem *, int percent);
 
 private:
     bool m_ran;
     bool m_killed;
     QString m_log;
     QString m_label;
-    QTime m_estimateTime;
+    QElapsedTimer m_estimateTime;
     int m_startingPercent;
-    QTime m_totalTime;
+    QElapsedTimer m_totalTime;
     QScopedPointer<PostJobAction> m_postJobAction;
+    QThread::Priority m_priority;
 };
 
 #endif // ABSTRACTJOB_H
