@@ -28,14 +28,16 @@
 #include <QRegularExpression>
 #include <Logger.h>
 
-FfmpegJob::FfmpegJob(const QString& name, const QStringList& args, bool isOpenLog)
-    : AbstractJob(name)
+FfmpegJob::FfmpegJob(const QString &name, const QStringList &args, bool isOpenLog,
+                     QThread::Priority priority)
+    : AbstractJob(name, priority)
     , m_outputMsgRead(false)
     , m_totalFrames(0)
     , m_previousPercent(0)
     , m_isOpenLog(isOpenLog)
 {
-    QAction* action = new QAction(tr("Open"), this);
+    QAction *action = new QAction(tr("Open"), this);
+    action->setData("Open");
     connect(action, SIGNAL(triggered()), this, SLOT(onOpenTriggered()));
     m_successActions << action;
     m_args.append(args);
@@ -44,7 +46,7 @@ FfmpegJob::FfmpegJob(const QString& name, const QStringList& args, bool isOpenLo
 
 FfmpegJob::~FfmpegJob()
 {
-    if (objectName().contains("proxies") && objectName().contains(".pending.")){
+    if (objectName().contains("proxies") && objectName().contains(".pending.")) {
         QFile::remove(objectName());
     }
 }
@@ -58,6 +60,14 @@ void FfmpegJob::start()
     AbstractJob::start(ffmpegPath.absoluteFilePath(), m_args);
 }
 
+void FfmpegJob::stop()
+{
+    write("q");
+    QTimer::singleShot(3000, this, [this]() {
+        AbstractJob::stop();
+    });
+}
+
 void FfmpegJob::onOpenTriggered()
 {
     if (m_isOpenLog) {
@@ -82,8 +92,7 @@ void FfmpegJob::onReadyRead()
             m_duration = msg.mid(msg.indexOf("Duration:") + 9);
             m_duration = m_duration.left(m_duration.indexOf(','));
             emit progressUpdated(m_item, 0);
-        }
-        else if (!m_outputMsgRead) {
+        } else if (!m_outputMsgRead) {
             // Wait for the "Output" then read the output fps to calculate number of frames.
             if (msg.contains("Output ")) {
                 m_outputMsgRead = true;
@@ -102,8 +111,7 @@ void FfmpegJob::onReadyRead()
             Mlt::Properties props;
             props.set("_profile", profile.get_profile(), 0);
             m_totalFrames = props.time_to_frames(m_duration.toLatin1().constData());
-        }
-        else if (msg.startsWith("frame=") && m_totalFrames > 0) {
+        } else if (msg.startsWith("frame=") && m_totalFrames > 0) {
             msg = msg.mid(msg.indexOf("frame=") + 6);
             msg = msg.left(msg.indexOf(" fps"));
             int frame = msg.toInt();
