@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 Meltytech, LLC
+ * Copyright (c) 2016-2022 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,10 +25,14 @@ class FfmpegJob : public AbstractJob
 {
     Q_OBJECT
 public:
-    FfmpegJob(const QString& name, const QStringList& args, bool isOpenLog = true);
+    FfmpegJob(const QString &name, const QStringList &args, bool isOpenLog = true,
+              QThread::Priority priority = Settings.jobPriority());
     virtual ~FfmpegJob();
     void start();
 
+public slots:
+    virtual void stop();
+
 private slots:
     void onOpenTriggered();
     void onReadyRead();
