@@ -124,8 +124,10 @@ public:
     void copyFilters(Mlt::Producer *producer = nullptr);
     void pasteFilters(Mlt::Producer *producer = nullptr, Mlt::Producer *fromProducer = nullptr);
     static void adjustFilters(Mlt::Producer &producer, int startIndex = 0);
-    static void adjustFilter(Mlt::Filter *filter, int in, int out, int inDelta, int outDelta);
-    static void adjustClipFilters(Mlt::Producer &producer, int in, int out, int inDelta, int outDelta);
+    static void adjustFilter(Mlt::Filter *filter, int in, int out, int inDelta, int outDelta,
+                             int keyframeDelta);
+    static void adjustClipFilters(Mlt::Producer &producer, int in, int out, int inDelta, int outDelta,
+                                  int keyframeDelta);
     bool hasFiltersOnClipboard() const
     {
         return m_filtersClipboard->is_valid() && m_filtersClipboard->filter_count() > 0;
