@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Meltytech, LLC
+ * Copyright (c) 2012-2022 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,18 +33,18 @@ OpenOtherDialog::OpenOtherDialog(QWidget *parent) :
 
     QScopedPointer<Mlt::Properties> mltProducers(MLT.repository()->producers());
     QScopedPointer<Mlt::Properties> mltFilters(MLT.repository()->filters());
-    QTreeWidgetItem* group = new QTreeWidgetItem(ui->treeWidget, QStringList(tr("Network")));
+    QTreeWidgetItem *group = new QTreeWidgetItem(ui->treeWidget, QStringList(tr("Network")));
     group->setData(0, Qt::UserRole, ui->networkTab->objectName());
     ui->treeWidget->setCurrentItem(group);
 
     // populate the device group
     group = new QTreeWidgetItem(ui->treeWidget, QStringList(tr("Device")));
     if (mltProducers->get_data("decklink")) {
-        QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("SDI/HDMI")));
+        QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("SDI/HDMI")));
         item->setData(0, Qt::UserRole, ui->decklinkTab->objectName());
     }
 #if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
-    QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Video4Linux")));
+    QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Video4Linux")));
     item->setData(0, Qt::UserRole, ui->v4lTab->objectName());
     item = new QTreeWidgetItem(group, QStringList(tr("PulseAudio")));
     item->setData(0, Qt::UserRole, ui->pulseTab->objectName());
@@ -57,57 +57,62 @@ OpenOtherDialog::OpenOtherDialog(QWidget *parent) :
     item->setData(0, Qt::UserRole, ui->x11grabTab->objectName());
 #endif
 #elif defined(Q_OS_WIN)
-    QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Audio/Video Device")));
+    QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Audio/Video Device")));
     item->setData(0, Qt::UserRole, ui->dshowVideoTab->objectName());
 #if ENABLE_SCREEN_CAPTURE
     item = new QTreeWidgetItem(group, QStringList(tr("Screen")));
     item->setData(0, Qt::UserRole, ui->gdigrabTab->objectName());
 #endif
 #elif defined(Q_OS_MAC)
-    QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Audio/Video Device")));
+    QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Audio/Video Device")));
     item->setData(0, Qt::UserRole, ui->avfoundationTab->objectName());
 #endif
 
     // populate the generators
     group = new QTreeWidgetItem(ui->treeWidget, QStringList(tr("Generator")));
     if (mltProducers->get_data("color")) {
-        QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Color")));
+        QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Color")));
         item->setData(0, Qt::UserRole, ui->colorTab->objectName());
-        if (!Settings.playerGPU() && mltProducers->get_data("qtext") && mltFilters->get_data("dynamictext")) {
-            QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Text")));
+        if (!Settings.playerGPU() && mltProducers->get_data("qtext")
+                && mltFilters->get_data("dynamictext")) {
+            QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Text")));
             item->setData(0, Qt::UserRole, ui->textTab->objectName());
         }
     }
+    if (mltProducers->get_data("glaxnimate")) {
+        QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Animation")));
+        item->setData(0, Qt::UserRole, ui->glaxnimateTab->objectName());
+    }
     if (mltProducers->get_data("noise")) {
-        QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Noise")));
+        QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Noise")));
         item->setData(0, Qt::UserRole, ui->noiseTab->objectName());
     }
     if (mltProducers->get_data("frei0r.ising0r")) {
-        QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Ising")));
+        QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Ising")));
         item->setData(0, Qt::UserRole, ui->isingTab->objectName());
     }
     if (mltProducers->get_data("frei0r.lissajous0r")) {
-        QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Lissajous")));
+        QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Lissajous")));
         item->setData(0, Qt::UserRole, ui->lissajousTab->objectName());
     }
     if (mltProducers->get_data("frei0r.plasma")) {
-        QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Plasma")));
+        QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Plasma")));
         item->setData(0, Qt::UserRole, ui->plasmaTab->objectName());
     }
     if (mltProducers->get_data("frei0r.test_pat_B")) {
-        QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Color Bars")));
+        QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Color Bars")));
         item->setData(0, Qt::UserRole, ui->colorbarsTab->objectName());
     }
     if (mltProducers->get_data("tone")) {
-        QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Audio Tone")));
+        QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Audio Tone")));
         item->setData(0, Qt::UserRole, ui->toneTab->objectName());
     }
     if (mltProducers->get_data("count")) {
-        QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Count")));
+        QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Count")));
         item->setData(0, Qt::UserRole, ui->countTab->objectName());
     }
     if (mltProducers->get_data("blipflash")) {
-        QTreeWidgetItem* item = new QTreeWidgetItem(group, QStringList(tr("Blip Flash")));
+        QTreeWidgetItem *item = new QTreeWidgetItem(group, QStringList(tr("Blip Flash")));
         item->setData(0, Qt::UserRole, ui->blipTab->objectName());
     }
     ui->treeWidget->expandAll();
@@ -118,17 +123,17 @@ OpenOtherDialog::~OpenOtherDialog()
     delete ui;
 }
 
-Mlt::Producer* OpenOtherDialog::newProducer(Mlt::Profile& profile, QObject* widget) const
+Mlt::Producer *OpenOtherDialog::newProducer(Mlt::Profile &profile, QObject *widget) const
 {
-    return dynamic_cast<AbstractProducerWidget*>(widget)->newProducer(profile);
+    return dynamic_cast<AbstractProducerWidget *>(widget)->newProducer(profile);
 }
 
-Mlt::Producer* OpenOtherDialog::newProducer(Mlt::Profile& profile) const
+Mlt::Producer *OpenOtherDialog::newProducer(Mlt::Profile &profile) const
 {
     return newProducer(profile, m_current);
 }
 
-void OpenOtherDialog::load(Mlt::Producer* producer)
+void OpenOtherDialog::load(Mlt::Producer *producer)
 {
     if (producer && producer->is_valid()) {
         QString service(producer->get("mlt_service"));
@@ -152,6 +157,8 @@ void OpenOtherDialog::load(Mlt::Producer* producer)
             selectTreeWidget(tr("SDI/HDMI"));
         else if (service == "color")
             selectTreeWidget(tr("Color"));
+        else if (service == "glaxnimate")
+            selectTreeWidget(tr("Animation"));
         else if (service == "noise")
             selectTreeWidget(tr("Noise"));
         else if (service == "frei0r.ising0r")
@@ -168,14 +175,14 @@ void OpenOtherDialog::load(Mlt::Producer* producer)
             selectTreeWidget(tr("Count"));
         else if (service == "blipflash")
             selectTreeWidget(tr("Blip Flash"));
-        dynamic_cast<AbstractProducerWidget*>(m_current)->loadPreset(*producer);
+        dynamic_cast<AbstractProducerWidget *>(m_current)->loadPreset(*producer);
     }
 }
 
-void OpenOtherDialog::selectTreeWidget(const QString& s)
+void OpenOtherDialog::selectTreeWidget(const QString &s)
 {
     for (int j = 0; j < ui->treeWidget->topLevelItemCount(); j++) {
-        QTreeWidgetItem* group = ui->treeWidget->topLevelItem(j);
+        QTreeWidgetItem *group = ui->treeWidget->topLevelItem(j);
         for (int i = 0; i < group->childCount(); i++) {
             if (group->child(i)->text(0) == s) {
                 ui->treeWidget->setCurrentItem(group->child(i));
@@ -185,7 +192,7 @@ void OpenOtherDialog::selectTreeWidget(const QString& s)
     }
 }
 
-void OpenOtherDialog::on_treeWidget_currentItemChanged(QTreeWidgetItem *current, QTreeWidgetItem*)
+void OpenOtherDialog::on_treeWidget_currentItemChanged(QTreeWidgetItem *current, QTreeWidgetItem *)
 {
     if (current->data(0, Qt::UserRole).isValid()) {
         QString currentData(current->data(0, Qt::UserRole).toString());
@@ -193,7 +200,7 @@ void OpenOtherDialog::on_treeWidget_currentItemChanged(QTreeWidgetItem *current,
             QString tabName(ui->methodTabWidget->widget(i)->objectName());
             if (currentData == tabName) {
                 ui->methodTabWidget->setCurrentIndex(i);
-                QWidget* w = ui->methodTabWidget->currentWidget();
+                QWidget *w = ui->methodTabWidget->currentWidget();
                 if (w == ui->networkTab)
                     m_current = ui->networkWidget;
                 else if (w == ui->decklinkTab)
@@ -204,6 +211,8 @@ void OpenOtherDialog::on_treeWidget_currentItemChanged(QTreeWidgetItem *current,
                     m_current = ui->colorWidget;
                 else if (w == ui->textTab)
                     m_current = ui->textWidget;
+                else if (w == ui->glaxnimateTab)
+                    m_current = ui->glaxnimateWidget;
                 else if (w == ui->noiseTab)
                     m_current = ui->noiseWidget;
                 else if (w == ui->isingTab)
