@@ -33,23 +33,24 @@
 #include <Logger.h>
 #include <utime.h>
 
-static const char* kProxySubfolder = "proxies";
-static const char* kProxyVideoExtension = ".mp4";
-static const char* kGoProProxyVideoExtension = ".LRV";
-static const char* kProxyPendingVideoExtension = ".pending.mp4";
-static const char* kProxyImageExtension = ".jpg";
-static const char* kProxyPendingImageExtension = ".pending.jpg";
+static const char *kProxySubfolder = "proxies";
+static const char *kProxyVideoExtension = ".mp4";
+static const char *kGoProProxyVideoExtension = ".LRV";
+static const char *kProxyPendingVideoExtension = ".pending.mp4";
+static const char *kProxyImageExtension = ".jpg";
+static const char *kProxyPendingImageExtension = ".pending.jpg";
 static const float kProxyResolutionRatio = 1.3f;
 static const int   kFallbackProxyResolution = 540;
 static const QStringList kPixFmtsWithAlpha = {"pal8", "argb", "rgba", "abgr",
-    "bgra", "yuva420p", "yuva422p", "yuva444p", "yuva420p9be", "yuva420p9le",
-    "yuva422p9be", "yuva422p9le", "yuva444p9be", "yuva444p9le", "yuva420p10be",
-    "yuva420p10le", "yuva422p10be", "yuva422p10le", "yuva444p10be", "yuva444p10le",
-    "yuva420p16be", "yuva420p16le", "yuva422p16be", "yuva422p16le", "yuva444p16be",
-    "yuva444p16le", "rgba64be", "rgba64le", "bgra64be", "bgra64le", "ya8",
-    "ya16le", "ya16be", "gbrap", "gbrap16le", "gbrap16be", "ayuv64le", "ayuv64be",
-    "gbrap12le", "gbrap12be", "gbrap10le", "gbrap10be", "gbrapf32be",
-    "gbrapf32le", "yuva422p12be", "yuva422p12le", "yuva444p12be", "yuva444p12le"};
+                                              "bgra", "yuva420p", "yuva422p", "yuva444p", "yuva420p9be", "yuva420p9le",
+                                              "yuva422p9be", "yuva422p9le", "yuva444p9be", "yuva444p9le", "yuva420p10be",
+                                              "yuva420p10le", "yuva422p10be", "yuva422p10le", "yuva444p10be", "yuva444p10le",
+                                              "yuva420p16be", "yuva420p16le", "yuva422p16be", "yuva422p16le", "yuva444p16be",
+                                              "yuva444p16le", "rgba64be", "rgba64le", "bgra64be", "bgra64le", "ya8",
+                                              "ya16le", "ya16be", "gbrap", "gbrap16le", "gbrap16be", "ayuv64le", "ayuv64be",
+                                              "gbrap12le", "gbrap12be", "gbrap10le", "gbrap10be", "gbrapf32be",
+                                              "gbrapf32le", "yuva422p12be", "yuva422p12le", "yuva444p12be", "yuva444p12le"
+                                             };
 
 QDir ProxyManager::dir()
 {
@@ -67,7 +68,7 @@ QDir ProxyManager::dir()
     return dir;
 }
 
-QString ProxyManager::resource(Mlt::Service& producer)
+QString ProxyManager::resource(Mlt::Service &producer)
 {
     QString resource = QString::fromUtf8(producer.get("resource"));
     if (producer.get_int(kIsProxyProperty) && producer.get(kOriginalResourceProperty)) {
@@ -78,7 +79,8 @@ QString ProxyManager::resource(Mlt::Service& producer)
     return resource;
 }
 
-void ProxyManager::generateVideoProxy(Mlt::Producer& producer, bool fullRange, ScanMode scanMode, const QPoint& aspectRatio, bool replace)
+void ProxyManager::generateVideoProxy(Mlt::Producer &producer, bool fullRange, ScanMode scanMode,
+                                      const QPoint &aspectRatio, bool replace)
 {
     // Always regenerate per preview scaling or 540 if not specified
     QString resource = ProxyManager::resource(producer);
@@ -99,7 +101,8 @@ void ProxyManager::generateVideoProxy(Mlt::Producer& producer, bool fullRange, S
     args << "-i" << resource;
     args << "-max_muxing_queue_size" << "9999";
     // transcode all streams except data, subtitles, and attachments
-    auto audioIndex = producer.property_exists(kDefaultAudioIndexProperty)? producer.get_int(kDefaultAudioIndexProperty) : producer.get_int("audio_index");
+    auto audioIndex = producer.property_exists(kDefaultAudioIndexProperty) ? producer.get_int(
+                          kDefaultAudioIndexProperty) : producer.get_int("audio_index");
     if (producer.get_int("video_index") < audioIndex) {
         args << "-map" << "0:V?" << "-map" << "0:a?";
     } else {
@@ -111,10 +114,11 @@ void ProxyManager::generateVideoProxy(Mlt::Producer& producer, bool fullRange, S
     if (scanMode == Automatic) {
         filters = QString("yadif=deint=interlaced,");
     } else if (scanMode != Progressive) {
-        filters = QString("yadif=parity=%1,").arg(scanMode == InterlacedTopFieldFirst? "tff" : "bff");
+        filters = QString("yadif=parity=%1,").arg(scanMode == InterlacedTopFieldFirst ? "tff" : "bff");
     }
     filters += QString("scale=width=-2:height=%1").arg(resolution());
-    if (Settings.proxyUseHardware() && (hwCodecs.contains("hevc_vaapi") || hwCodecs.contains("h264_vaapi"))) {
+    if (Settings.proxyUseHardware() && (hwCodecs.contains("hevc_vaapi")
+                                        || hwCodecs.contains("h264_vaapi"))) {
         hwFilters = ",format=nv12,hwupload";
     }
     if (fullRange) {
@@ -210,7 +214,7 @@ void ProxyManager::generateVideoProxy(Mlt::Producer& producer, bool fullRange, S
     args << "-g" << "1" << "-bf" << "0";
     args << "-y" << fileName;
 
-    FfmpegJob* job = new FfmpegJob(fileName, args, true);
+    FfmpegJob *job = new FfmpegJob(fileName, args, true);
     job->setLabel(QObject::tr("Make proxy for %1").arg(Util::baseName(resource)));
     if (replace) {
         job->setPostJobAction(new ProxyReplacePostJobAction(resource, fileName, hash));
@@ -220,7 +224,7 @@ void ProxyManager::generateVideoProxy(Mlt::Producer& producer, bool fullRange, S
     JOBS.add(job);
 }
 
-void ProxyManager::generateImageProxy(Mlt::Producer& producer, bool replace)
+void ProxyManager::generateImageProxy(Mlt::Producer &producer, bool replace)
 {
     // Always regenerate per preview scaling or 540 if not specified
     QString resource = ProxyManager::resource(producer);
@@ -235,7 +239,7 @@ void ProxyManager::generateImageProxy(Mlt::Producer& producer, bool replace)
     file.resize(0);
     file.close();
 
-    AbstractJob* job = new QImageJob(fileName, resource, resolution());
+    AbstractJob *job = new QImageJob(fileName, resource, resolution());
     if (replace) {
         job->setPostJobAction(new ProxyReplacePostJobAction(resource, fileName, hash));
     } else {
@@ -246,14 +250,15 @@ void ProxyManager::generateImageProxy(Mlt::Producer& producer, bool replace)
 
 typedef QPair<QString, QString> MltProperty;
 
-static void processProperties(QXmlStreamWriter& newXml, QVector<MltProperty>& properties, const QString& root)
+static void processProperties(QXmlStreamWriter &newXml, QVector<MltProperty> &properties,
+                              const QString &root)
 {
     // Determine if this is a proxy resource
     bool isProxy = false;
     QString newResource;
     QString service;
     QString speed = "1";
-    for (const auto& p: properties) {
+    for (const auto &p : properties) {
         if (p.first == kIsProxyProperty) {
             isProxy = true;
         } else if (p.first == kOriginalResourceProperty) {
@@ -267,10 +272,10 @@ static void processProperties(QXmlStreamWriter& newXml, QVector<MltProperty>& pr
         }
     }
     QVector<MltProperty> newProperties;
-    QVector<MltProperty>& propertiesRef = properties;
+    QVector<MltProperty> &propertiesRef = properties;
     if (isProxy) {
         // Filter the properties
-        for (const auto& p: properties) {
+        for (const auto &p : properties) {
             // Replace the resource property if proxy
             if (p.first == "resource") {
                 // Convert to relative
@@ -284,7 +289,7 @@ static void processProperties(QXmlStreamWriter& newXml, QVector<MltProperty>& pr
                 }
             } else if (p.first == "warp_resource") {
                 newProperties << MltProperty(p.first, newResource);
-            // Remove special proxy and original resource properties
+                // Remove special proxy and original resource properties
             } else if (p.first != kIsProxyProperty && p.first != kOriginalResourceProperty) {
                 newProperties << MltProperty(p.first, p.second);
             }
@@ -292,7 +297,7 @@ static void processProperties(QXmlStreamWriter& newXml, QVector<MltProperty>& pr
         propertiesRef = newProperties;
     }
     // Write all of the property elements
-    for (const auto& p : propertiesRef) {
+    for (const auto &p : propertiesRef) {
         newXml.writeStartElement("property");
         newXml.writeAttribute("name", p.first);
         newXml.writeCharacters(p.second);
@@ -302,7 +307,7 @@ static void processProperties(QXmlStreamWriter& newXml, QVector<MltProperty>& pr
     properties.clear();
 }
 
-bool ProxyManager::filterXML(QString& xmlString, QString root)
+bool ProxyManager::filterXML(QString &xmlString, QString root)
 {
     QString output;
     QXmlStreamReader xml(xmlString);
@@ -335,7 +340,8 @@ bool ProxyManager::filterXML(QString& xmlString, QString root)
             newXml.writeEntityReference(xml.name().toString());
             break;
         case QXmlStreamReader::ProcessingInstruction:
-            newXml.writeProcessingInstruction(xml.processingInstructionTarget().toString(), xml.processingInstructionData().toString());
+            newXml.writeProcessingInstruction(xml.processingInstructionTarget().toString(),
+                                              xml.processingInstructionData().toString());
             break;
         case QXmlStreamReader::StartDocument:
             newXml.writeStartDocument(xml.documentVersion().toString(), xml.isStandaloneDocument());
@@ -356,7 +362,7 @@ bool ProxyManager::filterXML(QString& xmlString, QString root)
                 processProperties(newXml, properties, root);
                 // Write the new start element
                 newXml.writeStartElement(xml.namespaceUri().toString(), element);
-                for (const auto& a : xml.attributes()) {
+                for (const auto &a : xml.attributes()) {
                     newXml.writeAttribute(a);
                 }
             }
@@ -384,7 +390,7 @@ bool ProxyManager::filterXML(QString& xmlString, QString root)
     return false;
 }
 
-bool ProxyManager::fileExists(Mlt::Producer& producer)
+bool ProxyManager::fileExists(Mlt::Producer &producer)
 {
     QDir proxyDir(Settings.proxyFolder());
     QDir projectDir(MLT.projectFolder());
@@ -403,7 +409,7 @@ bool ProxyManager::fileExists(Mlt::Producer& producer)
     return (projectDir.cd(kProxySubfolder) && projectDir.exists(fileName)) || proxyDir.exists(fileName);
 }
 
-bool ProxyManager::filePending(Mlt::Producer& producer)
+bool ProxyManager::filePending(Mlt::Producer &producer)
 {
     QDir proxyDir(Settings.proxyFolder());
     QDir projectDir(MLT.projectFolder());
@@ -419,7 +425,7 @@ bool ProxyManager::filePending(Mlt::Producer& producer)
     return (projectDir.cd(kProxySubfolder) && projectDir.exists(fileName)) || proxyDir.exists(fileName);
 }
 
-bool ProxyManager::isValidImage(Mlt::Producer& producer)
+bool ProxyManager::isValidImage(Mlt::Producer &producer)
 {
     QString service = QString::fromLatin1(producer.get("mlt_service"));
     if ((service == "qimage" || service == "pixbuf") && !producer.get_int(kShotcutSequenceProperty)) {
@@ -454,16 +460,18 @@ bool ProxyManager::isValidVideo(Mlt::Producer producer)
         bool coverArt = codec_name == "mjpeg" && frame_rate == "90000";
         key = QString("meta.attr.%1.stream.alpha_mode.markup").arg(video_index);
         bool alpha_mode = producer.get_int(key.toLatin1().constData());
-        LOG_DEBUG() << "pix_fmt =" << pix_fmt << " codec.frame_rate =" << frame_rate << " alpha_mode =" << alpha_mode;
+        LOG_DEBUG() << "pix_fmt =" << pix_fmt << " codec.frame_rate =" << frame_rate << " alpha_mode =" <<
+                    alpha_mode;
         return !kPixFmtsWithAlpha.contains(pix_fmt) && !alpha_mode && !coverArt;
     }
     return false;
 }
 
 // Returns true if the producer exists and was updated with proxy info
-bool ProxyManager::generateIfNotExists(Mlt::Producer& producer, bool replace)
+bool ProxyManager::generateIfNotExists(Mlt::Producer &producer, bool replace)
 {
-    if (Settings.proxyEnabled() && producer.is_valid() && !producer.get_int(kDisableProxyProperty) && !producer.get_int(kIsProxyProperty)) {
+    if (Settings.proxyEnabled() && producer.is_valid() && !producer.get_int(kDisableProxyProperty)
+            && !producer.get_int(kIsProxyProperty)) {
         if (ProxyManager::fileExists(producer)) {
             QString service = QString::fromLatin1(producer.get("mlt_service"));
             QDir projectDir(MLT.projectFolder());
@@ -499,16 +507,20 @@ bool ProxyManager::generateIfNotExists(Mlt::Producer& producer, bool replace)
                 // Tag this producer so we do not try to generate proxy again in this session
                 delete producer.get_frame();
                 auto threshold = qRound(kProxyResolutionRatio * resolution());
-                LOG_DEBUG() << producer.get_int("meta.media.width") << "x" << producer.get_int("meta.media.height") << "threshold" << threshold;
-                if (producer.get_int("meta.media.width") > threshold && producer.get_int("meta.media.height") > threshold) {
+                LOG_DEBUG() << producer.get_int("meta.media.width") << "x" << producer.get_int("meta.media.height")
+                            << "threshold" << threshold;
+                if (producer.get_int("meta.media.width") > threshold
+                        && producer.get_int("meta.media.height") > threshold) {
                     ProxyManager::generateVideoProxy(producer, MLT.fullRange(producer), Automatic, QPoint(), replace);
                 }
             } else if (isValidImage(producer)) {
                 // Tag this producer so we do not try to generate proxy again in this session
                 delete producer.get_frame();
                 auto threshold = qRound(kProxyResolutionRatio * resolution());
-                LOG_DEBUG() << producer.get_int("meta.media.width") << "x" << producer.get_int("meta.media.height") << "threshold" << threshold;
-                if (producer.get_int("meta.media.width") > threshold && producer.get_int("meta.media.height") > threshold) {
+                LOG_DEBUG() << producer.get_int("meta.media.width") << "x" << producer.get_int("meta.media.height")
+                            << "threshold" << threshold;
+                if (producer.get_int("meta.media.width") > threshold
+                        && producer.get_int("meta.media.height") > threshold) {
                     ProxyManager::generateImageProxy(producer, replace);
                 }
             }
@@ -517,29 +529,29 @@ bool ProxyManager::generateIfNotExists(Mlt::Producer& producer, bool replace)
     return false;
 }
 
-const char* ProxyManager::videoFilenameExtension()
+const char *ProxyManager::videoFilenameExtension()
 {
     return kProxyVideoExtension;
 }
 
-const char* ProxyManager::pendingVideoExtension()
+const char *ProxyManager::pendingVideoExtension()
 {
     return kProxyPendingVideoExtension;
 }
 
-const char* ProxyManager::imageFilenameExtension()
+const char *ProxyManager::imageFilenameExtension()
 {
     return kProxyImageExtension;
 }
 
-const char* ProxyManager::pendingImageExtension()
+const char *ProxyManager::pendingImageExtension()
 {
     return kProxyImageExtension;
 }
 
 int ProxyManager::resolution()
 {
-    return Settings.playerPreviewScale()? Settings.playerPreviewScale() : kFallbackProxyResolution;
+    return Settings.playerPreviewScale() ? Settings.playerPreviewScale() : kFallbackProxyResolution;
 }
 
 class FindNonProxyProducersParser : public Mlt::Parser
@@ -551,41 +563,94 @@ private:
 public:
     FindNonProxyProducersParser() : Mlt::Parser() {}
 
-    QList<Mlt::Producer>& producers() { return m_producers; }
+    QList<Mlt::Producer> &producers()
+    {
+        return m_producers;
+    }
 
-    int on_start_filter(Mlt::Filter*) { return 0; }
-    int on_start_producer(Mlt::Producer* producer) {
+    int on_start_filter(Mlt::Filter *)
+    {
+        return 0;
+    }
+    int on_start_producer(Mlt::Producer *producer)
+    {
         if (!producer->parent().get_int(kIsProxyProperty))
             m_producers << Mlt::Producer(producer);
         return 0;
     }
-    int on_end_producer(Mlt::Producer*) { return 0; }
-    int on_start_playlist(Mlt::Playlist*) { return 0; }
-    int on_end_playlist(Mlt::Playlist*) { return 0; }
-    int on_start_tractor(Mlt::Tractor*) { return 0; }
-    int on_end_tractor(Mlt::Tractor*) { return 0; }
-    int on_start_multitrack(Mlt::Multitrack*) { return 0; }
-    int on_end_multitrack(Mlt::Multitrack*) { return 0; }
-    int on_start_track() { return 0; }
-    int on_end_track() { return 0; }
-    int on_end_filter(Mlt::Filter*) { return 0; }
-    int on_start_transition(Mlt::Transition*) { return 0; }
-    int on_end_transition(Mlt::Transition*) { return 0; }
-    int on_start_chain(Mlt::Chain* chain) {
+    int on_end_producer(Mlt::Producer *)
+    {
+        return 0;
+    }
+    int on_start_playlist(Mlt::Playlist *)
+    {
+        return 0;
+    }
+    int on_end_playlist(Mlt::Playlist *)
+    {
+        return 0;
+    }
+    int on_start_tractor(Mlt::Tractor *)
+    {
+        return 0;
+    }
+    int on_end_tractor(Mlt::Tractor *)
+    {
+        return 0;
+    }
+    int on_start_multitrack(Mlt::Multitrack *)
+    {
+        return 0;
+    }
+    int on_end_multitrack(Mlt::Multitrack *)
+    {
+        return 0;
+    }
+    int on_start_track()
+    {
+        return 0;
+    }
+    int on_end_track()
+    {
+        return 0;
+    }
+    int on_end_filter(Mlt::Filter *)
+    {
+        return 0;
+    }
+    int on_start_transition(Mlt::Transition *)
+    {
+        return 0;
+    }
+    int on_end_transition(Mlt::Transition *)
+    {
+        return 0;
+    }
+    int on_start_chain(Mlt::Chain *chain)
+    {
         if (!chain->parent().get_int(kIsProxyProperty))
             m_producers << Mlt::Producer(chain);
         return 0;
     }
-    int on_end_chain(Mlt::Chain*) { return 0; }
-    int on_start_link(Mlt::Link*) { return 0; }
-    int on_end_link(Mlt::Link*) { return 0; }
+    int on_end_chain(Mlt::Chain *)
+    {
+        return 0;
+    }
+    int on_start_link(Mlt::Link *)
+    {
+        return 0;
+    }
+    int on_end_link(Mlt::Link *)
+    {
+        return 0;
+    }
 };
 
-void ProxyManager::generateIfNotExistsAll(Mlt::Producer& producer)
+void ProxyManager::generateIfNotExistsAll(Mlt::Producer &producer)
 {
     FindNonProxyProducersParser parser;
     parser.start(producer);
-    for (auto& clip : parser.producers()) {
+    for (auto &clip : parser.producers()) {
         generateIfNotExists(clip, false /* replace */);
     }
 }
@@ -602,7 +667,7 @@ bool ProxyManager::removePending()
     if (dir.exists()) {
         dir.setNameFilters(QStringList() << "*.pending.*");
         dir.setFilter(QDir::Files | QDir::NoDotAndDotDot | QDir::Writable);
-        for (const auto& s : dir.entryList()) {
+        for (const auto &s : dir.entryList()) {
             LOG_INFO() << "removing" << dir.filePath(s);
             foundAny |= QFile::remove(dir.filePath(s));
         }
@@ -611,7 +676,7 @@ bool ProxyManager::removePending()
     return foundAny;
 }
 
-QString ProxyManager::GoProProxyFilePath(const QString& resource)
+QString ProxyManager::GoProProxyFilePath(const QString &resource)
 {
     auto fi = QFileInfo(resource);
     auto base = fi.baseName();
