@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2021 Meltytech, LLC
+ * Copyright (c) 2013-2022 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -113,6 +113,15 @@ QUrl QmlMetadata::vuiFilePath() const
     return retVal;
 }
 
+void QmlMetadata::setIconFileName(const QUrl &fileName)
+{
+    if (fileName.isRelative()) {
+        m_icon = QUrl::fromLocalFile(m_path.absoluteFilePath(fileName.toLocalFile()));
+    } else {
+        m_icon = fileName;
+    }
+}
+
 void QmlMetadata::setIsAudio(bool isAudio)
 {
     m_isAudio = isAudio;
@@ -139,7 +148,7 @@ void QmlMetadata::setIsFavorite(bool isFavorite)
     emit changed();
 }
 
-void QmlMetadata::setGpuAlt(const QString& gpuAlt)
+void QmlMetadata::setGpuAlt(const QString &gpuAlt)
 {
     m_gpuAlt = gpuAlt;
     emit changed();
@@ -165,7 +174,7 @@ bool QmlMetadata::isMltVersion(const QString &version)
     return true;
 }
 
-QmlKeyframesMetadata::QmlKeyframesMetadata(QObject* parent)
+QmlKeyframesMetadata::QmlKeyframesMetadata(QObject *parent)
     : QObject(parent)
     , m_allowTrim(true)
     , m_allowAnimateIn(false)
@@ -175,7 +184,7 @@ QmlKeyframesMetadata::QmlKeyframesMetadata(QObject* parent)
 {
 }
 
-void QmlKeyframesMetadata::checkVersion(const QString& version)
+void QmlKeyframesMetadata::checkVersion(const QString &version)
 {
     if (!m_minimumVersion.isEmpty()) {
         LOG_DEBUG() << "MLT version:" << version << "Shotcut minimumVersion:" << m_minimumVersion;
@@ -189,7 +198,7 @@ void QmlKeyframesMetadata::setDisabled()
     m_enabled = m_allowAnimateIn = m_allowAnimateOut = false;
 }
 
-QmlKeyframesParameter::QmlKeyframesParameter(QObject* parent)
+QmlKeyframesParameter::QmlKeyframesParameter(QObject *parent)
     : QObject(parent)
     , m_isCurve(false)
     , m_minimum(0.0)
