@@ -19,7 +19,7 @@
 #include "qmlprofile.h"
 #include "mltcontroller.h"
 
-QmlProfile& QmlProfile::singleton()
+QmlProfile &QmlProfile::singleton()
 {
     static QmlProfile instance;
     return instance;
@@ -49,3 +49,8 @@ double QmlProfile::fps() const
 {
     return MLT.profile().fps();
 }
+
+double QmlProfile::sar() const
+{
+    return MLT.profile().sar();
+}
