@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2020 Meltytech, LLC
+ * Copyright (c) 2013-2022 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,11 +16,13 @@
  */
 
 #include "settings.h"
+#include <QApplication>
 #include <QColor>
 #include <QLocale>
 #include <QStandardPaths>
 #include <QFile>
 #include <QDir>
+#include <QAudioDeviceInfo>
 #include <Logger.h>
 
 static const QString APP_DATA_DIR_KEY("appdatadir");
@@ -35,7 +37,7 @@ ShotcutSettings &ShotcutSettings::singleton()
         if (appDataForSession.isEmpty()) {
             instance.reset(new ShotcutSettings);
             if (instance->settings.value(APP_DATA_DIR_KEY).isValid()
-                && QFile::exists(instance->settings.value(APP_DATA_DIR_KEY).toString() + SHOTCUT_INI_FILENAME) )
+                    && QFile::exists(instance->settings.value(APP_DATA_DIR_KEY).toString() + SHOTCUT_INI_FILENAME) )
                 instance.reset(new ShotcutSettings(instance->settings.value(APP_DATA_DIR_KEY).toString()));
         } else {
             instance.reset(new ShotcutSettings(appDataForSession));
@@ -44,7 +46,7 @@ ShotcutSettings &ShotcutSettings::singleton()
     return *instance;
 }
 
-ShotcutSettings::ShotcutSettings(const QString& appDataLocation)
+ShotcutSettings::ShotcutSettings(const QString &appDataLocation)
     : QObject()
     , settings(appDataLocation + SHOTCUT_INI_FILENAME, QSettings::IniFormat)
     , m_appDataLocation(appDataLocation)
@@ -74,7 +76,7 @@ QString ShotcutSettings::language() const
     return language;
 }
 
-void ShotcutSettings::setLanguage(const QString& s)
+void ShotcutSettings::setLanguage(const QString &s)
 {
     settings.setValue("language", s);
 }
@@ -91,10 +93,11 @@ void ShotcutSettings::setImageDuration(double d)
 
 QString ShotcutSettings::openPath() const
 {
-    return settings.value("openPath", QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
+    return settings.value("openPath",
+                          QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
 }
 
-void ShotcutSettings::setOpenPath(const QString& s)
+void ShotcutSettings::setOpenPath(const QString &s)
 {
     settings.setValue("openPath", s);
     emit savePathChanged();
@@ -102,10 +105,11 @@ void ShotcutSettings::setOpenPath(const QString& s)
 
 QString ShotcutSettings::savePath() const
 {
-    return settings.value("savePath", QStandardPaths::standardLocations(QStandardPaths::DocumentsLocation)).toString();
+    return settings.value("savePath",
+                          QStandardPaths::standardLocations(QStandardPaths::DocumentsLocation)).toString();
 }
 
-void ShotcutSettings::setSavePath(const QString& s)
+void ShotcutSettings::setSavePath(const QString &s)
 {
     settings.setValue("savePath", s);
     emit savePathChanged();
@@ -116,7 +120,7 @@ QStringList ShotcutSettings::recent() const
     return settings.value("recent").toStringList();
 }
 
-void ShotcutSettings::setRecent(const QStringList& ls)
+void ShotcutSettings::setRecent(const QStringList &ls)
 {
     if (ls.isEmpty())
         settings.remove("recent");
@@ -129,17 +133,21 @@ QString ShotcutSettings::theme() const
     return settings.value("theme", "dark").toString();
 }
 
-void ShotcutSettings::setTheme(const QString& s)
+void ShotcutSettings::setTheme(const QString &s)
 {
     settings.setValue("theme", s);
 }
 
-QString ShotcutSettings::jobPriority() const
+QThread::Priority ShotcutSettings::jobPriority() const
 {
-    return settings.value("jobPriority", "low").toString();
+    const auto priority = settings.value("jobPriority", "low").toString();
+    if (priority == "low") {
+        return QThread::LowPriority;
+    }
+    return QThread::NormalPriority;
 }
 
-void ShotcutSettings::setJobPriority(const QString& s)
+void ShotcutSettings::setJobPriority(const QString &s)
 {
     settings.setValue("jobPriority", s);
 }
@@ -190,7 +198,7 @@ QByteArray ShotcutSettings::windowGeometry() const
     return settings.value("geometry").toByteArray();
 }
 
-void ShotcutSettings::setWindowGeometry(const QByteArray& a)
+void ShotcutSettings::setWindowGeometry(const QByteArray &a)
 {
     settings.setValue("geometry", a);
 }
@@ -200,7 +208,7 @@ QByteArray ShotcutSettings::windowGeometryDefault() const
     return settings.value("geometryDefault").toByteArray();
 }
 
-void ShotcutSettings::setWindowGeometryDefault(const QByteArray& a)
+void ShotcutSettings::setWindowGeometryDefault(const QByteArray &a)
 {
     settings.setValue("geometryDefault", a);
 }
@@ -210,7 +218,7 @@ QByteArray ShotcutSettings::windowState() const
     return settings.value("windowState").toByteArray();
 }
 
-void ShotcutSettings::setWindowState(const QByteArray& a)
+void ShotcutSettings::setWindowState(const QByteArray &a)
 {
     settings.setValue("windowState", a);
 }
@@ -220,7 +228,7 @@ QByteArray ShotcutSettings::windowStateDefault() const
     return settings.value("windowStateDefault").toByteArray();
 }
 
-void ShotcutSettings::setWindowStateDefault(const QByteArray& a)
+void ShotcutSettings::setWindowStateDefault(const QByteArray &a)
 {
     settings.setValue("windowStateDefault", a);
 }
@@ -230,7 +238,7 @@ QString ShotcutSettings::viewMode() const
     return settings.value("playlist/viewMode").toString();
 }
 
-void ShotcutSettings::setViewMode(const QString& viewMode)
+void ShotcutSettings::setViewMode(const QString &viewMode)
 {
     settings.setValue("playlist/viewMode", viewMode);
     emit viewModeChanged();
@@ -241,17 +249,18 @@ QString ShotcutSettings::exportFrameSuffix() const
     return settings.value("exportFrameSuffix", ".png").toString();
 }
 
-void ShotcutSettings::setExportFrameSuffix(const QString& exportFrameSuffix)
+void ShotcutSettings::setExportFrameSuffix(const QString &exportFrameSuffix)
 {
     settings.setValue("exportFrameSuffix", exportFrameSuffix);
 }
 
 QString ShotcutSettings::encodePath() const
 {
-    return settings.value("encode/path", QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
+    return settings.value("encode/path",
+                          QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
 }
 
-void ShotcutSettings::setEncodePath(const QString& s)
+void ShotcutSettings::setEncodePath(const QString &s)
 {
     settings.setValue("encode/path", s);
 }
@@ -281,7 +290,7 @@ QStringList ShotcutSettings::encodeHardware() const
     return settings.value("encode/hardware").toStringList();
 }
 
-void ShotcutSettings::setEncodeHardware(const QStringList& ls)
+void ShotcutSettings::setEncodeHardware(const QStringList &ls)
 {
     if (ls.isEmpty())
         settings.remove("encode/hardware");
@@ -349,7 +358,7 @@ QString ShotcutSettings::playerDeinterlacer() const
     return result;
 }
 
-void ShotcutSettings::setPlayerDeinterlacer(const QString& s)
+void ShotcutSettings::setPlayerDeinterlacer(const QString &s)
 {
     settings.setValue("player/deinterlacer", s);
 }
@@ -358,10 +367,10 @@ QString ShotcutSettings::playerExternal() const
 {
     auto result = settings.value("player/external", "").toString();
     // "sdi" is no longer supported DVEO VidPort
-    return result == "sdi"? "" : result;
+    return result == "sdi" ? "" : result;
 }
 
-void ShotcutSettings::setPlayerExternal(const QString& s)
+void ShotcutSettings::setPlayerExternal(const QString &s)
 {
     settings.setValue("player/external", s);
 }
@@ -371,7 +380,7 @@ QString ShotcutSettings::playerGamma() const
     return settings.value("player/gamma", "bt709").toString();
 }
 
-void ShotcutSettings::setPlayerGamma(const QString& s)
+void ShotcutSettings::setPlayerGamma(const QString &s)
 {
     settings.setValue("player/gamma", s);
 }
@@ -392,7 +401,7 @@ QString ShotcutSettings::playerInterpolation() const
     return settings.value("player/interpolation", "bilinear").toString();
 }
 
-void ShotcutSettings::setPlayerInterpolation(const QString& s)
+void ShotcutSettings::setPlayerInterpolation(const QString &s)
 {
     settings.setValue("player/interpolation", s);
 }
@@ -437,7 +446,7 @@ QString ShotcutSettings::playerProfile() const
     return settings.value("player/profile", "").toString();
 }
 
-void ShotcutSettings::setPlayerProfile(const QString& s)
+void ShotcutSettings::setPlayerProfile(const QString &s)
 {
     settings.setValue("player/profile", s);
 }
@@ -512,12 +521,22 @@ void ShotcutSettings::setPlayerVideoDelayMs(int i)
     settings.setValue("player/videoDelayMs", i);
 }
 
+double ShotcutSettings::playerJumpSeconds() const
+{
+    return settings.value("player/jumpSeconds", 60.0).toDouble();
+}
+
+void ShotcutSettings::setPlayerJumpSeconds(double i)
+{
+    settings.setValue("player/jumpSeconds", i);
+}
+
 QString ShotcutSettings::playlistThumbnails() const
 {
     return settings.value("playlist/thumbnails", "small").toString();
 }
 
-void ShotcutSettings::setPlaylistThumbnails(const QString& s)
+void ShotcutSettings::setPlaylistThumbnails(const QString &s)
 {
     settings.setValue("playlist/thumbnails", s);
     emit playlistThumbnailsChanged();
@@ -653,11 +672,39 @@ void ShotcutSettings::setTimelineFramebufferWaveform(bool b)
     emit timelineFramebufferWaveformChanged();
 }
 
-QString ShotcutSettings::filterFavorite(const QString& filterName)
+int ShotcutSettings::audioReferenceTrack() const
+{
+    return settings.value("timeline/audioReferenceTrack", 0).toInt();
+}
+void ShotcutSettings::setAudioReferenceTrack(int track)
+{
+    settings.setValue("timeline/audioReferenceTrack", track);
+}
+
+double ShotcutSettings::audioReferenceSpeedRange() const
+{
+    return settings.value("timeline/audioReferenceSpeedRange", 0).toDouble();
+}
+void ShotcutSettings::setAudioReferenceSpeedRange(double range)
+{
+    settings.setValue("timeline/audioReferenceSpeedRange", range);
+}
+
+bool ShotcutSettings::timelinePreviewTransition() const
+{
+    return settings.value("timeline/previewTransition", true).toBool();
+}
+
+void ShotcutSettings::setTimelinePreviewTransition(bool b)
+{
+    settings.setValue("timeline/previewTransition", b);
+}
+
+QString ShotcutSettings::filterFavorite(const QString &filterName)
 {
     return settings.value("filter/favorite/" + filterName, "").toString();
 }
-void ShotcutSettings::setFilterFavorite(const QString& filterName, const QString& value)
+void ShotcutSettings::setFilterFavorite(const QString &filterName, const QString &value)
 {
     settings.setValue("filter/favorite/" + filterName, value);
 }
@@ -718,17 +765,17 @@ void ShotcutSettings::setAskOutputFilter(bool b)
     emit askOutputFilterChanged();
 }
 
-bool ShotcutSettings::loudnessScopeShowMeter(const QString& meter) const
+bool ShotcutSettings::loudnessScopeShowMeter(const QString &meter) const
 {
     return settings.value("scope/loudness/" + meter, true).toBool();
 }
 
-void ShotcutSettings::setLoudnessScopeShowMeter(const QString& meter, bool b)
+void ShotcutSettings::setLoudnessScopeShowMeter(const QString &meter, bool b)
 {
     settings.setValue("scope/loudness/" + meter, b);
 }
 
-void ShotcutSettings::setMarkerColor(const QColor& color)
+void ShotcutSettings::setMarkerColor(const QColor &color)
 {
     settings.setValue("markers/color", color.name());
 }
@@ -738,12 +785,12 @@ QColor ShotcutSettings::markerColor() const
     return QColor(settings.value("markers/color", "green").toString());
 }
 
-void ShotcutSettings::setMarkersShowColumn(const QString& column, bool b)
+void ShotcutSettings::setMarkersShowColumn(const QString &column, bool b)
 {
     settings.setValue("markers/columns/" + column, b);
 }
 
-bool ShotcutSettings::markersShowColumn(const QString& column) const
+bool ShotcutSettings::markersShowColumn(const QString &column) const
 {
     return settings.value("markers/columns/" + column, true).toBool();
 }
@@ -821,7 +868,7 @@ QString ShotcutSettings::appDataLocation() const
         return QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
 }
 
-void ShotcutSettings::setAppDataForSession(const QString& location)
+void ShotcutSettings::setAppDataForSession(const QString &location)
 {
     // This is intended to be called when using a command line option
     // to set the AppData location.
@@ -830,7 +877,7 @@ void ShotcutSettings::setAppDataForSession(const QString& location)
         instance.reset(new ShotcutSettings(location));
 }
 
-void ShotcutSettings::setAppDataLocally(const QString& location)
+void ShotcutSettings::setAppDataLocally(const QString &location)
 {
     // This is intended to be called when using a GUI action to set the
     // the new AppData location.
@@ -838,7 +885,7 @@ void ShotcutSettings::setAppDataLocally(const QString& location)
     // Copy the existing settings if they exist.
     if (!QFile::exists(location + SHOTCUT_INI_FILENAME)) {
         QSettings newSettings(location + SHOTCUT_INI_FILENAME, QSettings::IniFormat);
-        foreach (const QString& key, settings.allKeys())
+        foreach (const QString &key, settings.allKeys())
             newSettings.setValue(key, settings.value(key));
         newSettings.sync();
     }
@@ -852,14 +899,15 @@ void ShotcutSettings::setAppDataLocally(const QString& location)
 QStringList ShotcutSettings::layouts() const
 {
     QStringList result;
-    for (const auto& s : settings.value("layout/layouts").toStringList()) {
+    for (const auto &s : settings.value("layout/layouts").toStringList()) {
         if (!s.startsWith("__"))
             result << s;
     }
     return result;
 }
 
-bool ShotcutSettings::setLayout(const QString& name, const QByteArray& geometry, const QByteArray& state)
+bool ShotcutSettings::setLayout(const QString &name, const QByteArray &geometry,
+                                const QByteArray &state)
 {
     bool isNew = false;
     QStringList layouts = Settings.layouts();
@@ -873,19 +921,19 @@ bool ShotcutSettings::setLayout(const QString& name, const QByteArray& geometry,
     return isNew;
 }
 
-QByteArray ShotcutSettings::layoutGeometry(const QString& name)
+QByteArray ShotcutSettings::layoutGeometry(const QString &name)
 {
     QString key = QString("layout/%1_geometry").arg(name);
     return settings.value(key).toByteArray();
 }
 
-QByteArray ShotcutSettings::layoutState(const QString& name)
+QByteArray ShotcutSettings::layoutState(const QString &name)
 {
     QString key = QString("layout/%1_state").arg(name);
     return settings.value(key).toByteArray();
 }
 
-bool ShotcutSettings::removeLayout(const QString& name)
+bool ShotcutSettings::removeLayout(const QString &name)
 {
     QStringList list = layouts();
     int index = list.indexOf(name);
@@ -924,7 +972,8 @@ void ShotcutSettings::setClearRecent(bool b)
 
 QString ShotcutSettings::projectsFolder() const
 {
-    return settings.value("projectsFolder", QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
+    return settings.value("projectsFolder",
+                          QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
 }
 
 void ShotcutSettings::setProjectsFolder(const QString &path)
@@ -932,6 +981,53 @@ void ShotcutSettings::setProjectsFolder(const QString &path)
     settings.setValue("projectsFolder", path);
 }
 
+QString ShotcutSettings::audioInput() const
+{
+    QString defaultValue  = "default";
+#if defined(Q_OS_MAC) || defined(Q_OS_WIN)
+    for (const auto &deviceInfo : QAudioDeviceInfo::availableDevices(QAudio::AudioInput)) {
+        defaultValue = deviceInfo.deviceName();
+    }
+#endif
+    return settings.value("audioInput", defaultValue).toString();
+}
+
+void ShotcutSettings::setAudioInput(const QString &name)
+{
+    settings.setValue("audioInput", name);
+}
+
+QString ShotcutSettings::videoInput() const
+{
+    return settings.value("videoInput").toString();
+}
+
+void ShotcutSettings::setVideoInput(const QString &name)
+{
+    settings.setValue("videoInput", name);
+}
+
+QString ShotcutSettings::glaxnimatePath() const
+{
+    QDir dir(qApp->applicationDirPath());
+    return settings.value("glaxnimatePath", dir.absoluteFilePath("glaxnimate")).toString();
+}
+
+void ShotcutSettings::setGlaxnimatePath(const QString &path)
+{
+    settings.setValue("glaxnimatePath", path);
+}
+
+bool ShotcutSettings::exportRangeMarkers() const
+{
+    return settings.value("exportRangeMarkers", true).toBool();
+}
+
+void ShotcutSettings::setExportRangeMarkers(bool b)
+{
+    settings.setValue("exportRangeMarkers", b);
+}
+
 bool ShotcutSettings::proxyEnabled() const
 {
     return settings.value("proxy/enabled", false).toBool();
@@ -945,7 +1041,7 @@ void ShotcutSettings::setProxyEnabled(bool b)
 QString ShotcutSettings::proxyFolder() const
 {
     QDir dir(appDataLocation());
-    const char* subfolder = "proxies";
+    const char *subfolder = "proxies";
     if (!dir.cd(subfolder)) {
         if (dir.mkdir(subfolder))
             dir.cd(subfolder);
@@ -953,7 +1049,7 @@ QString ShotcutSettings::proxyFolder() const
     return settings.value("proxy/folder", dir.path()).toString();
 }
 
-void ShotcutSettings::setProxyFolder(const QString& path)
+void ShotcutSettings::setProxyFolder(const QString &path)
 {
     settings.setValue("proxy/folder", path);
 }
@@ -978,6 +1074,43 @@ void ShotcutSettings::setProxyUseHardware(bool b)
     settings.setValue("proxy/useHardware", b);
 }
 
+void ShotcutSettings::clearShortcuts(const QString &name)
+{
+    QString key = "shortcuts/" + name;
+    settings.remove(key);
+}
+
+void ShotcutSettings::setShortcuts(const QString &name, const QList<QKeySequence> &shortcuts)
+{
+    QString key = "shortcuts/" + name;
+    QString shortcutSetting;
+    if (shortcuts.size() > 0)
+        shortcutSetting += shortcuts[0].toString();
+    shortcutSetting += "||";
+    if (shortcuts.size() > 1)
+        shortcutSetting += shortcuts[1].toString();
+    settings.setValue(key, shortcutSetting);
+}
+
+QList<QKeySequence> ShotcutSettings::shortcuts(const QString &name)
+{
+    QString key = "shortcuts/" + name;
+    QList<QKeySequence> shortcuts;
+    QString shortcutSetting = settings.value(key, "").toString();
+    if (!shortcutSetting.isEmpty()) {
+        for (const QString &s : shortcutSetting.split("||"))
+            shortcuts << QKeySequence::fromString(s);
+    }
+    return shortcuts;
+}
+
+void ShotcutSettings::reset()
+{
+    for (auto &key : settings.allKeys()) {
+        settings.remove(key);
+    }
+}
+
 int ShotcutSettings::undoLimit() const
 {
     return settings.value("undoLimit", 1000).toInt();
