@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2020 Meltytech, LLC
+ * Copyright (c) 2014-2022 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,8 @@
 #include "mltcontroller.h"
 #include "util.h"
 #include "shotcut_mlt_properties.h"
-#include "Logger.h"
+#include "settings.h"
+#include <Logger.h>
 #include <QString>
 #include <QDir>
 #include <QFileInfo>
@@ -53,23 +54,33 @@ DirectShowVideoWidget::DirectShowVideoWidget(QWidget *parent) :
     bool isVideo = true;
     QString description;
     QString name;
+    auto currentVideo = 1;
+    auto currentAudio = 1;
     if (started && finished && proc.exitStatus() == QProcess::NormalExit) {
         QString output = proc.readAll();
-        foreach (const QString& line, output.split(QRegularExpression("[\r\n]"), QString::SkipEmptyParts)) {
-            if (line.contains("DirectShow audio devices"))
-                isVideo = false;
-            auto i = line.indexOf("]  \"");
+        foreach (const QString &line, output.split(QRegularExpression("[\r\n]"), Qt::SkipEmptyParts)) {
+            auto i = line.indexOf("] \"");
             if (i > -1) {
-                description = line.mid(i + 4).replace('\"', "");
+                auto j = line.indexOf("\" (");
+                if (j > -1) {
+                    description = line.mid(i + 3, j - i - 3);
+                    isVideo = line.midRef(j + 3).startsWith("video");
+                }
             } else {
-                QString s("]     Alternative name \"");
+                QString s("]   Alternative name \"");
                 i = line.indexOf(s);
                 if (i > -1) {
                     name = line.mid(i + s.size()).replace('\"', "");
-                    LOG_DEBUG() << (isVideo? "video" : "audio") << description << name;
+                    LOG_DEBUG() << (isVideo ? "video" : "audio") << description << name;
                     if (isVideo) {
+                        if (Settings.videoInput() == name) {
+                            currentVideo = ui->videoCombo->count();
+                        }
                         ui->videoCombo->addItem(description, name);
                     } else {
+                        if (Settings.audioInput() == name) {
+                            currentAudio = ui->audioCombo->count();
+                        }
                         ui->audioCombo->addItem(description, name);
                     }
                 }
@@ -78,9 +89,9 @@ DirectShowVideoWidget::DirectShowVideoWidget(QWidget *parent) :
     }
 
     if (ui->videoCombo->count() > 1)
-        ui->videoCombo->setCurrentIndex(1);
+        ui->videoCombo->setCurrentIndex(currentVideo);
     if (ui->audioCombo->count() > 1)
-        ui->audioCombo->setCurrentIndex(1);
+        ui->audioCombo->setCurrentIndex(currentAudio);
 #endif
 }
 
@@ -89,21 +100,21 @@ DirectShowVideoWidget::~DirectShowVideoWidget()
     delete ui;
 }
 
-Mlt::Producer *DirectShowVideoWidget::newProducer(Mlt::Profile& profile)
+Mlt::Producer *DirectShowVideoWidget::newProducer(Mlt::Profile &profile)
 {
-    Mlt::Producer* p = 0;
+    Mlt::Producer *p = 0;
     if (ui->videoCombo->currentIndex() > 0) {
         LOG_DEBUG() << ui->videoCombo->currentData().toString();
         p = new Mlt::Producer(profile, QString("dshow:video=%1")
-                          .arg(ui->videoCombo->currentData().toString())
-                          .toUtf8().constData());
+                              .arg(ui->videoCombo->currentData().toString())
+                              .toUtf8().constData());
     }
     if (ui->audioCombo->currentIndex() > 0) {
-        Mlt::Producer* audio = new Mlt::Producer(profile,
-            QString("dshow:audio=%1").arg(ui->audioCombo->currentData().toString())
-                                     .toLatin1().constData());
+        Mlt::Producer *audio = new Mlt::Producer(profile,
+                                                 QString("dshow:audio=%1").arg(ui->audioCombo->currentData().toString())
+                                                 .toLatin1().constData());
         if (p && p->is_valid() && audio->is_valid()) {
-            Mlt::Tractor* tractor = new Mlt::Tractor;
+            Mlt::Tractor *tractor = new Mlt::Tractor;
             tractor->set("_profile", profile.get_profile(), 0);
             tractor->set("resource1", p->get("resource"));
             tractor->set("resource2", audio->get("resource"));
@@ -137,17 +148,24 @@ Mlt::Producer *DirectShowVideoWidget::newProducer(Mlt::Profile& profile)
     p->set("force_seekable", 0);
     p->set(kBackgroundCaptureProperty, 1);
     p->set(kShotcutCaptionProperty, tr("Audio/Video Device").toUtf8().constData());
+    if (ui->audioCombo->currentIndex() > 0) {
+        Settings.setAudioInput(ui->audioCombo->currentData().toString());
+    }
+    if (ui->videoCombo->currentIndex() > 0) {
+        Settings.setVideoInput(ui->videoCombo->currentData().toString());
+    }
     return p;
 }
 
 void DirectShowVideoWidget::setProducer(Mlt::Producer *producer)
 {
-    QString resource = producer->get("resource1") ? QString(producer->get("resource1")) : QString(producer->get("resource"));
+    QString resource = producer->get("resource1") ? QString(producer->get("resource1")) : QString(
+                           producer->get("resource"));
     QString resource2 = QString(producer->get("resource2"));
     LOG_DEBUG() << "resource" << resource;
     LOG_DEBUG() << "resource2" << resource2;
-    const char* videoDevice = "dshow:video=";
-    const char* audioDevice = "dshow:audio=";
+    const char *videoDevice = "dshow:video=";
+    const char *audioDevice = "dshow:audio=";
     ui->videoCombo->setCurrentIndex(0);
     ui->audioCombo->setCurrentIndex(0);
     if (resource.startsWith(videoDevice)) {
@@ -188,7 +206,7 @@ void DirectShowVideoWidget::on_videoCombo_activated(int index)
         emit producerChanged(0);
         QCoreApplication::processEvents();
 
-        Mlt::Producer* p = newProducer(MLT.profile());
+        Mlt::Producer *p = newProducer(MLT.profile());
         AbstractProducerWidget::setProducer(p);
         MLT.setProducer(p);
         MLT.play();
