@@ -28,21 +28,21 @@
 #include <QProgressBar>
 #include <QVBoxLayout>
 
-ProducerPreviewWidget::ProducerPreviewWidget(double dar)
-  : QWidget()
-  , m_previewSize(320, 320)
-  , m_seekTo(-1)
-  , m_timerId(0)
-  , m_producer(nullptr)
-  , m_queue(10, DataQueue<QueueItem>::OverflowModeWait)
-  , m_generateFrames(false)
+ProducerPreviewWidget::ProducerPreviewWidget(double dar, int width)
+    : QWidget()
+    , m_previewSize(width, width)
+    , m_seekTo(-1)
+    , m_timerId(0)
+    , m_queue(10, DataQueue<QueueItem>::OverflowModeWait)
+    , m_generateFrames(false)
+    , m_isLooping(true)
 {
     LOG_DEBUG() << "begin";
-    int height = lrint((double)320 / dar);
-    height -= height %2;
+    int height = lrint((double)width / dar);
+    height -= height % 2;
     m_previewSize.setHeight( height );
 
-    QVBoxLayout* layout = new QVBoxLayout();
+    QVBoxLayout *layout = new QVBoxLayout();
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     setLayout(layout);
@@ -63,6 +63,7 @@ ProducerPreviewWidget::ProducerPreviewWidget(double dar)
     m_posLabel = new QLabel();
     m_posLabel->setAlignment(Qt::AlignCenter);
     layout->addWidget(m_posLabel);
+    connect(m_posLabel, SIGNAL(linkActivated(QString)), this, SLOT(restart()));
 
     LOG_DEBUG() << "end";
 }
@@ -72,18 +73,17 @@ ProducerPreviewWidget::~ProducerPreviewWidget()
     stop();
 }
 
-void ProducerPreviewWidget::start(Mlt::Producer* producer)
+void ProducerPreviewWidget::start(const Mlt::Producer &producer)
 {
     m_producer = producer;
 
-    if( m_producer )
-    {
+    if (m_producer.is_valid()) {
         // Set up the preview display and timer
         m_scrubber->setFramerate(MLT.profile().fps());
-        m_scrubber->setScale(m_producer->get_length());
+        m_scrubber->setScale(m_producer.get_length());
         // Display preview at half frame rate.
-        int miliseconds = 2* 1000.0 / MLT.profile().fps();
-        m_timerId = startTimer(miliseconds);
+        int milliseconds = 2 * 1000.0 / MLT.profile().fps();
+        m_timerId = startTimer(milliseconds);
         // Set up the producer frame generator
         m_seekTo = 0;
         m_generateFrames = true;
@@ -91,31 +91,26 @@ void ProducerPreviewWidget::start(Mlt::Producer* producer)
     }
 }
 
-void ProducerPreviewWidget::ProducerPreviewWidget::stop()
+void ProducerPreviewWidget::ProducerPreviewWidget::stop(bool releaseProducer)
 {
-    if( m_timerId )
-    {
+    if ( m_timerId ) {
         killTimer(m_timerId);
         m_timerId = 0;
     }
     m_generateFrames = false;
-    while( m_queue.count() > 0 )
-    {
+    while ( m_queue.count() > 0 ) {
         m_queue.pop();
     }
     m_future.waitForFinished();
-    if(m_producer)
-    {
-        delete m_producer;
-        m_producer = nullptr;
+    if (releaseProducer) {
+        m_producer = Mlt::Producer();
+        m_scrubber->setScale(0);
     }
-    while( m_queue.count() > 0 )
-    {
+    while ( m_queue.count() > 0 ) {
         m_queue.pop();
     }
     m_seekTo = 0;
     m_scrubber->onSeek(0);
-    m_scrubber->setScale(0);
     m_posLabel->setText("");
 }
 
@@ -124,63 +119,90 @@ void ProducerPreviewWidget::showText(QString text)
     m_imageLabel->setText(text);
 }
 
+void ProducerPreviewWidget::setLooping(bool enabled)
+{
+    m_isLooping = enabled;
+}
+
+void ProducerPreviewWidget::restart()
+{
+    stop(false);
+    start(m_producer);
+}
+
 void ProducerPreviewWidget::seeked(int position)
 {
     m_seekTo = position;
+    if (!m_generateFrames && m_producer.is_valid()) {
+        generateFrame();
+
+        QueueItem item;
+        while (m_queue.count()) {
+            item = m_queue.pop();
+        }
+        m_imageLabel->setPixmap(item.pixmap);
+        m_scrubber->onSeek(item.position);
+    }
 }
 
-void ProducerPreviewWidget::timerEvent(QTimerEvent*)
+void ProducerPreviewWidget::timerEvent(QTimerEvent *)
 {
-    if( m_queue.count() > 0 )
-    {
+    if ( m_queue.count() > 0 ) {
         QueueItem item = m_queue.pop();
         m_imageLabel->setPixmap(item.pixmap);
         m_scrubber->onSeek(item.position);
         m_posLabel->setText(item.positionText);
+    } else if (!m_generateFrames && m_timerId) {
+        stop(false);
+        m_posLabel->setText(QString("<p><b><a href=\"restart\">%1</a></b></p>").arg(tr("Play")));
     }
 }
 
 void ProducerPreviewWidget::frameGeneratorThread()
 {
-    while( m_generateFrames && m_producer )
-    {
-        // Check for seek
-        if(m_seekTo != -1)
-        {
-            m_producer->seek(m_seekTo);
-            m_seekTo = -1;
-            while( m_queue.count() > 1 )
-            {
-                m_queue.pop();
-            }
+    while (m_generateFrames && m_producer.is_valid()) {
+        generateFrame();
+    }
+}
+
+void ProducerPreviewWidget::generateFrame()
+{
+    // Check for seek
+    if (m_seekTo != -1) {
+        m_producer.seek(m_seekTo);
+        m_seekTo = -1;
+        while ( m_queue.count() > 1 ) {
+            m_queue.pop();
         }
-        // Get the image
-        int position = m_producer->position();
-        int length = m_producer->get_length();
-        int width = m_previewSize.width();
-        int height = m_previewSize.height();
-        mlt_image_format format = mlt_image_rgb;
-        Mlt::Frame* frame = m_producer->get_frame();
-        frame->set( "rescale.interp", "bilinear" );
-        uint8_t* mltImage = frame->get_image( format, width, height, 0 );
-        QImage image( mltImage, width, height, QImage::Format_RGB888 );
+    }
+    // Get the image
+    int position = m_producer.position();
+    int length = m_producer.get_length();
+    int width = m_previewSize.width();
+    int height = m_previewSize.height();
+    mlt_image_format format = mlt_image_rgb;
+    std::unique_ptr<Mlt::Frame> frame(m_producer.get_frame());
+    frame->set( "rescale.interp", "bilinear" );
+    uint8_t *mltImage = frame->get_image( format, width, height, 0 );
+    QImage image( mltImage, width, height, QImage::Format_RGB888 );
+
 
-        // Send the image and status in the queue
-        QueueItem item;
-        item.pixmap.convertFromImage(image);
-        item.position = position;
-        item.positionText = QString::fromLatin1(m_producer->frame_time()) + QString(" / ") + QString::fromLatin1(m_producer->get_length_time());
-        m_queue.push(item);
+    // Send the image and status in the queue
+    QueueItem item;
+    item.pixmap.convertFromImage(image);
+    item.position = position;
+    item.positionText = QString::fromLatin1(m_producer.frame_time()) + QString(" / ") +
+                        QString::fromLatin1(m_producer.get_length_time());
+    m_queue.push(item);
 
-        // Seek to the next frame (every other frame with repeat)
-        if(position + 2 >= length)
-        {
-            m_producer->seek(0);
-        }
-        else
-        {
-            m_producer->seek(position + 2);
+    // Seek to the next frame (every other frame with repeat)
+    if (position + 2 >= length) {
+        if (m_isLooping) {
+            m_producer.seek(0);
+        } else {
+            m_generateFrames = false;
         }
-        delete frame;
+    } else {
+        m_producer.seek(position + 2);
     }
 }
